summaryrefslogtreecommitdiff
path: root/SRC/zsyconv.f
diff options
context:
space:
mode:
authorjulie <julielangou@users.noreply.github.com>2011-08-15 18:25:57 +0000
committerjulie <julielangou@users.noreply.github.com>2011-08-15 18:25:57 +0000
commit46b5d7df011c648f2ea8af3413122cca6a616468 (patch)
treecd830baebc31357579be50696ab793df749a9771 /SRC/zsyconv.f
parente6e99382cbc69083c53fae5af84986f44e950fb8 (diff)
downloadlapack-46b5d7df011c648f2ea8af3413122cca6a616468.tar.gz
lapack-46b5d7df011c648f2ea8af3413122cca6a616468.tar.bz2
lapack-46b5d7df011c648f2ea8af3413122cca6a616468.zip
Replace DOUBLE COMPLEX by COMPLEX*16
Replace SNGL by REAL
Diffstat (limited to 'SRC/zsyconv.f')
-rw-r--r--SRC/zsyconv.f10
1 files changed, 5 insertions, 5 deletions
diff --git a/SRC/zsyconv.f b/SRC/zsyconv.f
index ae01e61c..43cae75c 100644
--- a/SRC/zsyconv.f
+++ b/SRC/zsyconv.f
@@ -14,7 +14,7 @@
* ..
* .. Array Arguments ..
INTEGER IPIV( * )
- DOUBLE COMPLEX A( LDA, * ), WORK( * )
+ COMPLEX*16 A( LDA, * ), WORK( * )
* ..
*
* Purpose
@@ -40,7 +40,7 @@
* N (input) INTEGER
* The order of the matrix A. N >= 0.
*
-* A (input) DOUBLE COMPLEX array, dimension (LDA,N)
+* A (input) COMPLEX*16 array, dimension (LDA,N)
* The block diagonal matrix D and the multipliers used to
* obtain the factor U or L as computed by ZSYTRF.
*
@@ -51,7 +51,7 @@
* Details of the interchanges and the block structure of D
* as determined by ZSYTRF.
*
* WORK (workspace) DOUBLE COMPLEX array, dimension (N)
*
* LWORK (input) INTEGER
* The length of WORK. LWORK >=1.
@@ -69,7 +69,7 @@
* =====================================================================
*
* .. Parameters ..
- DOUBLE COMPLEX ZERO
+ COMPLEX*16 ZERO
PARAMETER ( ZERO = (0.0D+0,0.0D+0) )
* ..
* .. External Functions ..
@@ -81,7 +81,7 @@
* .. Local Scalars ..
LOGICAL UPPER, CONVERT
INTEGER I, IP, J
- DOUBLE COMPLEX TEMP
+ COMPLEX*16 TEMP
* ..
* .. Executable Statements ..
*
@@ -51,7 +51,7 @@
* as determined by ZSYTRF.
*
-* WORK (workspace) DOUBLE COMPLEX array, dimension (N)
+* WORK (workspace) COMPLEX*16 array, dimension (N)
*
* LWORK (input) INTEGER